/*MakeDesc.Rex*/
  /*Gets decriptions out of files to 4Dos Descript.ion*/

  /*Copyright 1993 by Ronald Terry Constant
  Compuserve: 73677,1011*/

  /*I use the second line of source files as a description line
  that can be used for the Descript.Ion file used by 4Dos. MakeDesc.Rex
  reads that second line and puts it in the 4Dos Descript.Ion file.
  Thus, when I use Dir, I can see a description of my source files.
  The second line of this file above is an example. When MakeDesc.Rex is run,
  the second line of this REXX source file will be used as a description
  for this file.*/

  /*How to customize this routine:
    To change the line in a source file that you want read as
        a description, go to the Initialize procedure and
        change SrcDscLinNum = 2 to the line number you want
        to read
    To change the length of the description used, go to the
        Initialize procedure and change DscLen = 40 to the
        length you want to use.
    To change the sourecfiles processed and the characters used
        for comments in a source file, go to the ReadSrcFiles procedure
        and look at the If...Else If...Else If... that you see there
        add or change the EXT number of files you want processed
        and immediately under it, add or change the comment delimiter
        you want to use.
        For Example:
            Currently for "BTM" files I use '::' as a comment line.
            If you want to use the more normal 'REM' for a comment line
            to use as a description, simply change my '::' to 'REM'.
            If you want to use the entire line, with the '' delimiter from
            the template for the parse statement.*/

    /*Get command line arguments, in upper case*/
Arg  Help '/'FileSpec

        /*Do preparatory initializations and argument processing*/
    Call Initialize
    Call GetArgs
    Call DosFileList FileSpec

        /*Process the files and descriptions*/
    Call ReadDscFil
    Call ReadSrcFiles
    Call WriteDscFil

    Exit

/*ROUTINES-----------------------------------------------------------------*/
AddDesc: Procedure Expose FALSE TRUE DscList. DscNum Fil Dsc
    Parse Arg SrcFilNam, SrcFilDsc

    If SrcFilDsc = "" Then
        Return

    SrcFilNamFound = FALSE
    Do I = 1 To DscNum by 1
        If SrcFilNam = DscList.I.Fil Then
            Do
            DscList.I.Dsc = SrcFilDsc
            SrcFilNamFound = TRUE
            Say "Describe" Left(SrcFilNam,12) '"'SrcFilDsc'"'
            Leave
            End
        End

    If SrcFilNamFound = FALSE Then
        Do
        DscNum = DscNum + 1
        DscList.DscNum.Fil = SrcFilNam
        DscList.DscNum.Dsc = SrcFilDsc
        Say "Describe" Left(SrcFilNam,12) '"'SrcFilDsc'"'
        End

    Return

DosFileList: Procedure Expose FileList. FilNum
    /*Build a file list from a file spec which can include wildcards*/
    Arg FileSpec
    FilNum = 1

        /*See if the file spec exists at all*/
    FileList.FilNum = DosDir(FileSpec, "n")
        /*If exists, get all the files in FileList.*/
    Do While FileList.FilNum <> ""
        FilNum = FilNum + 1
        FileList.FilNum = DosDir(, "n")
        End

        /*Make the file count, FilNum, accurate*/
    FilNum = FilNum - 1
    Return

GetArgs:
    /*Process arguments passed to program. Look for ?*/

        /*Strip blanks/quotes/blanks from parameters*/
    FileSpec = Strip(Strip(Strip(FileSpec),,'"'))

    If FileSpec = "" Then
        FileSpec = "*.*"

        /*If request for help, Usage*/
    If (Pos("?",Help) > 0)Then
        Call Usage
    Return

Initialize:
    /*Initialize variables, etc.*/
    FALSE = 0
    TRUE  = 1

    SrcFilNam = ""
    SrcFilDsc = ""

     /*Change this line number to the line holding your descriptions*/
    SrcDscLinNum = 2
    DscLen = 40

    DscNum = 0
    Return

LineInNum: Procedure
    /*Read a specified line from a file*/
    /*Return **EOF** if the line doesn't exist*/
    Arg FileName, LineNum

    CurNum = 0
        /*Read file while not EOF*/
    Do While Lines(FileName) > 0
        CurNum = CurNum + 1
        CurLin = LineIn(FileName)
        If CurNum = LineNum Then
            Leave
        End

    If CurNum <> LineNum Then
        CurLin = "**EOF**"
    Return CurLin

ParseFdrive: Procedure
    /*Parse a FullPath to d - drive letter only, no ':'*/
    /*Use Call ParseFdrive DosFname(FileSpec) to insure fullpath*/
    Arg FileSpec
    FileParts = ParseFn(FileSpec)
    Drive = Word(FileParts, 1)
    If Drive = "-" Then
        Drive = ""
    Return Drive

ParseFpath: Procedure
    /*Parse a FullPath to \path\*/
    /*Use Call ParseFpath DosFname(FileSpec) to insure fullpath*/
    Arg FileSpec
    FileParts = ParseFn(FileSpec)
    Path = Word(FileParts, 2)
    If Path = "-" Then
        Path = ""
    Return Path

ParseFname: Procedure
    /*Parse a FullPath to name - name part of filename only, no '.'*/
    Arg FileSpec
    FileParts = ParseFn(FileSpec)
    Name = Word(FileParts, 3)
    If Name = "-" Then
        Name = ""
    Return Name

ParseFext: Procedure
    /*Parse a FullPath to Ext - no '.'*/
    Arg FileSpec
    FileParts = ParseFn(FileSpec)
    Ext = Word(FileParts, 4)
    If Ext = "-" Then
        Ext = ""
    Return Ext

ParseFfilename: Procedure
    /*Parse a FullPath to FilNam.Ext*/
    Arg FileSpec

    FileParts = ParseFn(FileSpec)
    FileName = Word(FileParts, 3)
    If (FileName <> "-") & (Word(FileParts, 4) <> "-") Then
        FileName = FileName"."Word(FileParts, 4)
    Else FileName = ""
    Return FileName

ParseFbase: Procedure
    /*Parse a FullPath to d:\Path\FilNam - no '.Ext'*/
    /*Use Call ParseFbase DosFname(FileSpec) to insure fullpath*/
    Arg FileSpec

    FileBase = ""
    FileParts = ParseFn(FileSpec)
    Do I = 1 To 3
        If Word(FileParts, I) \= "-" Then
            Do
            FileBase = FileBase||Word(FileParts,I)
            If I = 1 Then FileBase=FileBase":"
            End
    End
    Return FileBase

ReadDscFil:
    DscFilNam = "DESCRIPT.ION"
    Fil = "FIL"
    Dsc = "DSC"
    DscNum = 0
    Do While Lines(DscFilNam) > 0
        DscNum = DscNum + 1
        Parse Value LineIn(DscFilNam) With DscList.DscNum.Fil DscList.DscNum.Dsc
        DscList.DscNum.Fil = Upper(DscList.DscNum.Fil)
        End

    Return

ReadSrcFiles:
    Do Index = 1 to FilNum by 1
        SrcFilNam = FileList.Index
        SrcFilDsc = LineInNum(SrcFilNam, SrcDscLinNum)

        If ParseFext(SrcFilNam) = "BAT" Then
            Parse Value SrcFilDsc With '::'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "BTM" Then
            Parse Value SrcFilDsc With '::'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "CMM" Then
            Parse Value SrcFilDsc With '/*'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "C" Then
            Parse Value SrcFilDsc With '/*'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "H" Then
            Parse Value SrcFilDsc With '/*'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "PAS" Then
            Parse Value SrcFilDsc With '{'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "REX" Then
            Parse Value SrcFilDsc With '/*'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "WBM" Then
            Parse Value SrcFilDsc With ';;'SrcFilDsc
        Else If ParseFext(SrcFilNam) = "WBT" Then
            Parse Value SrcFilDsc With ';;'SrcFilDsc
        Else
            Do
            Call LineOut SrcFilNam
            Iterate
            End

        SrcFilDsc = Strip(SubStr(SrcFilDsc,1,DscLen))

        If SrcFilDsc <> '"**EOF**"' Then
            Do
            Call AddDesc SrcFilNam, SrcFilDsc
            End
        Call LineOut SrcFilNam
        End
    Return

Usage:
    Say "USAGE: MakeDesc.Rex [?] [/FileSpec]"
    Say "?          Displays this help message"
    Say "/FileSpec  Limits files processed to this file specification (default *.*)"
    Say ""
    Say "MakeDesc.Rex Reads a specified comment line (default is line 2)"
    Say "from source files that are specified in the program and uses the lines"
    Say "as 4Dos descriptions in Descript.Ion. See the comments at the beginning"
    Say "of MakeDesc.Rex on how to change the source files used, the line"
    Say "in each file read, and the length of the line to use. Each comment"
    Say "line read is converted to a 4Dos description. The default length"
    Say "used for descriptions is 40."
    Exit(0)
    Return

WriteDscFil: Procedure Expose FALSE TRUE DscFilNam DscNum DscList.
    DscFilExist = (DosDir(DscFilNam) <> "")
    If DscFilExist Then
        If Pos("H", DosDir(DscFilNam,"A")) > 0 Then
            FilHid = TRUE
        Else
            FilHid = FALSE
    Else
        FilHid = TRUE

    Call DosDel DscFilNam
    Do I = 1 to DscNum by 1
        Call LineOut DscFilNam, DscList.I.Fil DscList.I.Dsc
        End
    Call LineOut DscFilNam

    If FilHid Then
        Call DosChMod DscFilNam, "H"
    Return


